@@ -4,13 +4,28 @@ from .element import Element
 from .icon import Icon
 
 class Message(Element):
+    """Message widget
+
+    Args:
+    
+        message (string): message's text
+        opt_css_class (string, optional): option fomantic ui css class. Defaults to None.
+        desc (string, optional): message's description. Defaults to None.
+        icon (Icon, optional): message's icon. Defaults to None.
+        spacing (bool, optional): enable vertical spacing between elements. Defaults to False.
+        hideable (bool, optional): auto hide message (10s). Defaults to True.
+        
+    More Info:
+    
+        - See https://fomantic-ui.com/collections/message.html
+    """
     message = ValidProp(str)
     desc = ValidProp(str)
     opt_css_class = ValidProp(str)
-    has_segment = ValidProp(bool)
+    spacing = ValidProp(bool)
     icon = ValidProp(Icon)
     
-    def __init__(self, message, opt_css_class=None, desc=None, icon=None, has_segment=False, hideable=True):
+    def __init__(self, message, opt_css_class=None, desc=None, icon=None, spacing=False, hideable=True):
         super().__init__('div')
         self.message = message
         self.opt_css_class = ' ' + opt_css_class if opt_css_class else ''
@@ -18,7 +33,7 @@ class Message(Element):
         if icon:
             self.opt_css_class += ' icon'
         self.desc = desc
-        self.has_segment = has_segment
+        self.spacing = spacing
         self.css_class = 'hideable' if hideable else ''
         
         msg_box = Element('div', css_class=f'ui{self.opt_css_class} message')
@@ -30,7 +45,7 @@ class Message(Element):
             msg_content.append_inner(Element('p', inner_text=self.desc))
         msg_box.append_inner(msg_content)
         
-        if self.has_segment:
+        if self.spacing:
             segment = Segment(msg_box, opt_css_class='horizontally fitted basic')
             self.append_inner(segment)
         else:
